@@ -33,6 +33,38 @@ class DeleteTask(AbstractCommandLineInterface):
         annotation_list = self.service.wrapper.get_all_annotation_list(project_id, query_params=query_params)
         return annotation_list
 
+    def delete_input_data_list(self, project_id: str, input_data_id_list: List[str]):
+        """
+        タスクに使われていない入力データを削除する。
+        """
+        for input_data_id in input_data_id_list:
+            try:
+                input_data = self.service.wrapper.get_input_data_or_none(project_id, input_data_id)
+                if input_data is None:
+                    logger.debug(f"input_data_id='{input_data_id}'の入力データは存在しないため、削除できません。")
+                    continue
+
+                input_data_name = input_data["input_data_name"]
+                task_list = self.service.wrapper.get_all_tasks(
+                    project_id, query_params={"input_data_ids": input_data_id}
+                )
+
+                if len(task_list) > 0:
+                    used_task_id_list = [e["task_id"] for e in task_list]
+                    logger.debug(
+                        f"入力データ(input_data_id='{input_data_id}', "
+                        f"input_data_name='{input_data_name}')はタスクに使われているため、削除をスキップします。\n"
+                        f"task_id_list='{used_task_id_list}'"
+                    )
+                    continue
+
+                self.service.api.delete_input_data(project_id, input_data_id)
+
+            except requests.exceptions.HTTPError as e:
+                logger.warning(e)
+                logger.warning(f"input_data_id='{input_data_id}'の削除に失敗しました。")
+                continue
+
     def delete_task(
         self,
         project_id: str,
@@ -75,11 +107,14 @@ class DeleteTask(AbstractCommandLineInterface):
         logger.debug(f"task_id={task_id}: アノテーションが{len(annotation_list)}個付与されています。")
         if not force:
             if len(annotation_list) > 0:
-                logger.info(f"アノテーションが付与されているため（{len(annotation_list)}個）、タスク'{task_id}'を削除できません。")
+                logger.info(
+                    f"アノテーションが付与されているため（{len(annotation_list)}個）、タスク'{task_id}'の削除をスキップします。"
+                    f"削除するには`--force`を指定してください。"
+                )
                 return False
 
         if not match_task_with_query(Task.from_dict(task), task_query):
-            logger.debug(f"task_id={task_id}: TaskQueryの条件にマッチしないため、スキップします。")
+            logger.debug(f"task_id={task_id}: `--task_query`の条件にマッチしないため、スキップします。task_query={task_query}")
             return False
 
         if not self.confirm_delete_task(task_id):
@@ -119,7 +154,11 @@ class DeleteTask(AbstractCommandLineInterface):
     def main(self):
         args = self.args
         task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id)
-        self.delete_task_list(args.project_id, task_id_list=task_id_list, force=args.force)
+
+        dict_task_query = annofabcli.common.cli.get_json_from_args(args.task_query)
+        task_query: Optional[TaskQuery] = TaskQuery.from_dict(dict_task_query) if dict_task_query is not None else None
+
+        self.delete_task_list(args.project_id, task_id_list=task_id_list, force=args.force, task_query=task_query)
 
 
 def main(args):
